@@ -69,6 +69,8 @@
 
 Bhattacharya <- function(param, n_rnorm = 1000, savePlots = FALSE){
 
+    if(interactive()){
+
   res <- param
   if("midLengths" %in% names(res) == TRUE){
     midLengths <- as.character(res$midLengths)
@@ -202,9 +204,10 @@ Bhattacharya <- function(param, n_rnorm = 1000, savePlots = FALSE){
           title(xlab = "L", outer = TRUE, line = 2.5)
         }
         # identify regression line
-        if(xy > 1) rm(id.co1)
-        id.co1 <- identify(bhat.table$L, bhat.table$delta.log.N1.plus, n = 2, pos = TRUE)
-        if(length(id.co1$ind) == 0) break
+          if(xy > 1) rm(id.co1)
+              id.co1 <- identify(bhat.table$L, bhat.table$delta.log.N1.plus,
+                                 n = 2, pos = TRUE)
+              if(length(id.co1$ind) == 0) break
 
         colour.vec[id.co1$ind[1]:id.co1$ind[2]] <- colour.xy[xy]
         dev.off()
@@ -444,4 +447,9 @@ Bhattacharya <- function(param, n_rnorm = 1000, savePlots = FALSE){
     plot(ret)
     return(ret)
   }
+
+    }else{
+        writeLines("Interactive session needed for Bhattacharya.")
+        return(NULL)
+    }
 }
